@@ -1,7 +1,8 @@
 from .ci import confidence_intervals, percentage_confidence_intervals
-
+from .std import pooled_std
 
 __all__ = [
     'confidence_intervals',
-    'percentage_confidence_intervals'
+    'percentage_confidence_intervals',
+    'pooled_std'
 ]
